Class: RubyIndexer::Entry::UnresolvedMethodAlias
- Inherits:
-
RubyIndexer::Entry
- Object
- RubyIndexer::Entry
- RubyIndexer::Entry::UnresolvedMethodAlias
- Extended by:
- T::Sig
- Defined in:
- lib/ruby_indexer/lib/ruby_indexer/entry.rb
Overview
An unresolved method alias is an alias entry for which we aren't sure what the right hand side points to yet. For
example, if we have alias a b, we create an unresolved alias for a because we aren't sure immediate what b
is referring to
Instance Attribute Summary collapse
-
#new_name ⇒ Object
readonly
Returns the value of attribute new_name.
-
#old_name ⇒ Object
readonly
Returns the value of attribute old_name.
-
#owner ⇒ Object
readonly
Returns the value of attribute owner.
Attributes inherited from RubyIndexer::Entry
#comments, #file_path, #location, #name, #visibility
Instance Method Summary collapse
-
#initialize(new_name, old_name, owner, file_path, location, comments) ⇒ UnresolvedMethodAlias
constructor
rubocop:disable Metrics/ParameterLists.
Methods inherited from RubyIndexer::Entry
#file_name, #private?, #protected?, #public?
Constructor Details
#initialize(new_name, old_name, owner, file_path, location, comments) ⇒ UnresolvedMethodAlias
rubocop:disable Metrics/ParameterLists
512 513 514 515 516 517 518 |
# File 'lib/ruby_indexer/lib/ruby_indexer/entry.rb', line 512 def initialize(new_name, old_name, owner, file_path, location, comments) # rubocop:disable Metrics/ParameterLists super(new_name, file_path, location, comments) @new_name = new_name @old_name = old_name @owner = owner end |
Instance Attribute Details
#new_name ⇒ Object (readonly)
Returns the value of attribute new_name.
497 498 499 |
# File 'lib/ruby_indexer/lib/ruby_indexer/entry.rb', line 497 def new_name @new_name end |
#old_name ⇒ Object (readonly)
Returns the value of attribute old_name.
497 498 499 |
# File 'lib/ruby_indexer/lib/ruby_indexer/entry.rb', line 497 def old_name @old_name end |
#owner ⇒ Object (readonly)
Returns the value of attribute owner.
500 501 502 |
# File 'lib/ruby_indexer/lib/ruby_indexer/entry.rb', line 500 def owner @owner end |